# openbrewerydb-python

[![Build Status](https://travis-ci.org/jrbourbeau/openbrewerydb-python.svg?branch=master)](https://travis-ci.org/jrbourbeau/openbrewerydb-python)
[![GitHub license](https://img.shields.io/github/license/jrbourbeau/openbrewerydb-python.svg)](https://github.com/jrbourbeau/openbrewerydb-python/blob/master/LICENSE)


A Python wrapper for the [Open Brewery DB API](https://www.openbrewerydb.org/).


## Documentation

The documentation for openbrewerydb-python can be found at https://jrbourbeau.github.io/openbrewerydb-python/


## Installation

`openbrewerydb` can be installed using `pip`

```
pip install openbrewerydb
```

For more information see the [installation instructions](https://jrbourbeau.github.io/openbrewerydb-python/installation.html) in the [documentation](https://jrbourbeau.github.io/openbrewerydb-python/).


## License

[MIT License](LICENSE)
